@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: XObject.pm,v 1.6 2004/06/15 09:14:41 fredo Exp $
+#   $Id: XObject.pm,v 1.7 2004/12/16 00:30:53 fredo Exp $
 #
 #=======================================================================
 package PDF::API2::Resource::XObject;
@@ -44,9 +44,10 @@ BEGIN {
 
     @ISA = qw( PDF::API2::Resource );
 
-    ( $VERSION ) = '$Revision: 1.6 $' =~ /Revision: (\S+)\s/; # $Date: 2004/06/15 09:14:41 $
+    ( $VERSION ) = '$Revision: 1.7 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
 
 }
+no warnings qw[ deprecated recursion uninitialized ];
 
 =head1 $res = PDF::API2::Resource::XObject->new $pdf, $name
 
@@ -122,6 +123,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: XObject.pm,v $
+    Revision 1.7  2004/12/16 00:30:53  fredo
+    added no warn for recursion
+
     Revision 1.6  2004/06/15 09:14:41  fredo
     removed cr+lf
 
